Functions and Loops Mixed-Up Code Questions
--------------------------------------------

.. selectquestion:: Functions_Loops_MixedUpCode_1_sq
   :fromid: Functions_Loops_MixedUpCode_1, Functions_Loops_MixedUpCode_1_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_2_sq
   :fromid: Functions_Loops_MixedUpCode_2, Functions_Loops_MixedUpCode_2_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_3_sq
   :fromid: Functions_Loops_MixedUpCode_3, Functions_Loops_MixedUpCode_3_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_4_sq
   :fromid: Functions_Loops_MixedUpCode_4, Functions_Loops_MixedUpCode_4_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_5_sq
   :fromid: Functions_Loops_MixedUpCode_5, Functions_Loops_MixedUpCode_5_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_6_sq
   :fromid: Functions_Loops_MixedUpCode_6, Functions_Loops_MixedUpCode_6_ac
   :toggle:


.. selectquestion:: Functions_Loops_MixedUpCode_7_sq
   :fromid: Functions_Loops_MixedUpCode_7, Functions_Loops_MixedUpCode_7_ac
   :toggle:
